# pymautic
Python Mautic API


=============
Running Tests
=============


Tests require ```pip install pytest```.

You will need to set the following enviornment variables to a Mautic instance:

MAUTIC_URL
MAUTIC_USERNAME
MAUTIC_PASSWORD

The URL needs to look like https://mautic.example.com.


To run the unit tests ::

    $ py.test

